@@ -57,7 +57,7 @@ class HttpBodyReader(RawIOBase):
         self.eof = False
 
     def readinto(self, b):
-        if self.http_stream.parser.is_message_complete():
+        if self.http_stream.parser.is_message_complete() or self.eof:
             if  self.http_stream.parser.is_partial_body():
                 return self.http_stream.parser.recv_body_into(b)
             return 0
@@ -78,6 +78,8 @@ class HttpBodyReader(RawIOBase):
 
             if self.http_stream.parser.is_partial_body() or recved == 0:
                 break
+            elif self.http_stream.parser.is_message_complete():
+                break
         
         if not self.http_stream.parser.is_partial_body():
             self.eof = True
